==> docfbe_2_3_35_62.zip: docfbe_2_2_35_62/source/TCFbERowRowCachedTable.cpp <==
/*
    TCFbERowRowCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERowRowCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERowRowCachedTable::TCFbERowRowCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbERowRowCachedTable::TCFbERowRowCachedTable(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECachedTable(RowLabelList, RowLabelList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERowRowCachedTable::~TCFbERowRowCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbERowRowCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    if (!this->FIsLinkedToParent) {
        return;
    }

    for (int i = 0; i < this->GetNumberOfRows(); i++) {
        this->UnableElementByIndex(i, RowIndex);
        this->UnableElementByIndex(RowIndex, i);
    }
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERowRowCachedTable::ParentAddRow(AnsiString RowLabel)
{
    this->AddRow(RowLabel);
    return this->AddColumn(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERowRowCachedTable::ParentAddColumn(AnsiString ColumnLabel)
{
    return -1; // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERowRowCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteRowByIndex(TargetRowIndex);
    this->DeleteColumnByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERowRowCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    return; // Ȃ
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERowRowCachedTable::CreateClone(void)
{
    TCFbERowRowCachedTable* Clone = new TCFbERowRowCachedTable();
    Clone->Assign(this);
    return Clone;       
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERowRowCachedTable::CreateRotatedClone(void)
{
    TCFbERowRowCachedTable* Clone = new TCFbERowRowCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_39_68.zip: docfbe_2_3_39_68/source/TCFbERowRowCachedTable.cpp <==
/*
    TCFbERowRowCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERowRowCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERowRowCachedTable::TCFbERowRowCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbERowRowCachedTable::TCFbERowRowCachedTable(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECachedTable(RowLabelList, RowLabelList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERowRowCachedTable::~TCFbERowRowCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbERowRowCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    if (!this->FIsLinkedToParent) {
        return;
    }

    for (int i = 0; i < this->GetNumberOfRows(); i++) {
        this->UnableElementByIndex(i, RowIndex);
        this->UnableElementByIndex(RowIndex, i);
    }
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERowRowCachedTable::ParentAddRow(const char* RowLabel)
{
    this->AddRow(RowLabel);
    return this->AddColumn(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERowRowCachedTable::ParentAddColumn(const char* ColumnLabel)
{
    return -1; // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERowRowCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteRowByIndex(TargetRowIndex);
    this->DeleteColumnByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERowRowCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    return; // Ȃ
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERowRowCachedTable::CreateClone(void)
{
    TCFbERowRowCachedTable* Clone = new TCFbERowRowCachedTable();
    Clone->Assign(this);
    return Clone;       
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERowRowCachedTable::CreateRotatedClone(void)
{
    TCFbERowRowCachedTable* Clone = new TCFbERowRowCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------
